netapp_ontap.resources.nvme_subsystem_map API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nvme_subsystem_map`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

An NVMe subsystem map is an association of an NVMe namespace with an NVMe subsystem. When an NVMe namespace is mapped to an NVMe subsystem, the NVMe subsystem's hosts are granted access to the NVMe namespace. The relationship between an NVMe subsystem and an NVMe namespace is one subsystem to many namespaces.
The NVMe subsystem map REST API allows you to create, delete and discover NVMe subsystem maps.

## Examples

### Creating an NVMe subsystem map

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemMap

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NvmeSubsystemMap()
        resource.svm.name = "svm1"
        resource.subsystem.name = "subsystem1"
        resource.namespace.name = "/vol/vol1/namespace1"
        resource.post(hydrate=True)
        print(resource)

### Retrieving all of the NVMe subsystem maps

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemMap

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(NvmeSubsystemMap.get_collection()))

Try it out

    [
        NvmeSubsystemMap(
            {
                "subsystem": {
                    "uuid": "580a6b1e-fe43-11e8-91a0-005056a79967",
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/580a6b1e-fe43-11e8-91a0-005056a79967"
                        }
                    },
                    "name": "subsystem1",
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-maps/580a6b1e-fe43-11e8-91a0-005056a79967/3ccdedc6-2519-4206-bc1f-b0f4adab6f89"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "uuid": "0e91b214-fe40-11e8-91a0-005056a79967",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/0e91b214-fe40-11e8-91a0-005056a79967"
                        }
                    },
                },
                "namespace": {
                    "uuid": "3ccdedc6-2519-4206-bc1f-b0f4adab6f89",
                    "_links": {
                        "self": {
                            "href": "/api/storage/namespaces/3ccdedc6-2519-4206-bc1f-b0f4adab6f89"
                        }
                    },
                    "name": "/vol/vol1/namespace1",
                },
            }
        )
    ]

### Retrieving a specific NVMe subsystem map

The NVMe subsystem map is identified by the UUID of the NVMe subsystem followed by the UUID of the NVMe namespace.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemMap

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NvmeSubsystemMap(
            **{
                "namespace.uuid": "3ccdedc6-2519-4206-bc1f-b0f4adab6f89",
                "subsystem.uuid": "580a6b1e-fe43-11e8-91a0-005056a79967",
            }
        )
        resource.get()
        print(resource)

Try it out

    NvmeSubsystemMap(
        {
            "subsystem": {
                "uuid": "580a6b1e-fe43-11e8-91a0-005056a79967",
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystems/580a6b1e-fe43-11e8-91a0-005056a79967"
                    }
                },
                "name": "subsystem1",
            },
            "_links": {
                "self": {
                    "href": "/api/protocols/nvme/subsystem-maps/580a6b1e-fe43-11e8-91a0-005056a79967/3ccdedc6-2519-4206-bc1f-b0f4adab6f89"
                }
            },
            "svm": {
                "name": "svm1",
                "uuid": "0e91b214-fe40-11e8-91a0-005056a79967",
                "_links": {
                    "self": {"href": "/api/svm/svms/0e91b214-fe40-11e8-91a0-005056a79967"}
                },
            },
            "namespace": {
                "uuid": "3ccdedc6-2519-4206-bc1f-b0f4adab6f89",
                "_links": {
                    "self": {
                        "href": "/api/storage/namespaces/3ccdedc6-2519-4206-bc1f-b0f4adab6f89"
                    }
                },
                "node": {
                    "name": "node1",
                    "uuid": "012b4508-67d6-4788-8c2d-801f254ce976",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/012b4508-67d6-4788-8c2d-801f254ce976"
                        }
                    },
                },
                "name": "/vol/vol1/namespace1",
            },
            "nsid": "00000001h",
        }
    )

### Deleting an NVMe subsystem map

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemMap

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NvmeSubsystemMap(
            **{
                "namespace.uuid": "3ccdedc6-2519-4206-bc1f-b0f4adab6f89",
                "subsystem.uuid": "580a6b1e-fe43-11e8-91a0-005056a79967",
            }
        )
        resource.delete()

## Classes

`class NvmeSubsystemMap (*args, **kwargs)`

  An NVMe subsystem map is an association of an NVMe namespace with an NVMe subsystem. When an NVMe namespace is mapped to an NVMe subsystem, the NVMe subsystem's hosts are granted access to the NVMe namespace. The relationship between an NVMe subsystem and an NVMe namespace is one subsystem to many namespaces.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves NVMe subsystem maps.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `anagrpid`

    ### Related ONTAP commands

    - `vserver nvme subsystem map show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an NVMe subsystem map.

    ### Related ONTAP commands

    - `vserver nvme subsystem map delete`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves NVMe subsystem maps.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `anagrpid`

    ### Related ONTAP commands

    - `vserver nvme subsystem map show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves NVMe subsystem maps.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `anagrpid`

    ### Related ONTAP commands

    - `vserver nvme subsystem map show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an NVMe subsystem map.

    ### Related ONTAP commands

    - `vserver nvme subsystem map delete`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an NVMe subsystem map.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `anagrpid`

    ### Related ONTAP commands

    - `vserver nvme subsystem map show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an NVMe subsystem map.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the NVMe subsystem map.
    - `namespace.uuid` or `namespace.name` - Existing NVMe namespace to map to the specified NVme subsystem.
    - `subsystem.uuid` or `subsystem.name` - Existing NVMe subsystem to map to the specified NVMe namespace.

    ### Related ONTAP commands

    - `vserver nvme subsystem map create`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-maps`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class NvmeSubsystemMapSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemMap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `anagrpid GET`

    The Asymmetric Namespace Access Group ID (ANAGRPID) of the NVMe namespace.
    The format for an ANAGRPID is 8 hexadecimal digits (zero-filled) followed by a lower case "h".
    There is an added cost to retrieving this property's value. It is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

    Example: 00103050h

  `links GET`

    The links field of the nvme_subsystem_map.

  `namespace GET POST`

    The namespace field of the nvme_subsystem_map.

  `nsid GET`

    The NVMe namespace identifier. This is an identifier used by an NVMe controller to provide access to the NVMe namespace.
    The format for an NVMe namespace identifier is 8 hexadecimal digits (zero-filled) followed by a lower case "h".

    Example: 00000001h

  `subsystem GET POST`

    The subsystem field of the nvme_subsystem_map.

  `svm GET POST PATCH`

    The svm field of the nvme_subsystem_map.